# typescript-node-scripts

## Requirements

-   node `>=6.0.0`
-   yarn

**Note: npm is not supported at this stage for running and building, only bootstrapping is supported.**

## Getting Started

To create a new TypeScript + Node.js based app, run:

```sh
# run
npx typescript-node-scripts initApp <appName>

# get into the folder
cd <appName>

# go!
yarn start
```

## Commands

### `yarn start`

Starts the development server with watch mode and incremental builds. This command generates a bundle which is located at `build/bundle.js`.

#### Options

| Argument          | Description                                                                                        |
| ----------------- | -------------------------------------------------------------------------------------------------- |
| `--no-collapse`   | Expands all the collapsed errors                                                                   |
| `--no-auto-start` | Disables auto starting and stopping of the application. By default, it executes `build/bundle.js`. |

### `yarn build`

Builds a production ready bundle. This minifies all sources into one simple, distribuitable `dist/bundle.prod.js` which is ideal for Docker builds.

This command does not bundle any dependencies which is `require`-d or `import`-ed from `node_modules`!

#### Options

| Argument               | Description                                 |
| ---------------------- | ------------------------------------------- |
| `--no-collapse`        | Expands all the collapsed errors            |
| `--bypass-ci-warnings` | Bypass CI warnings being treated as errors. |

### `yarn test`

Runs the Jest test runners in watch mode by default. You can add in Jest options as usual.

#### Example commands

```sh
yarn test --coverage

yarn test --watchAll
```

## Tests
Jest is the main test runner that this package supports.

### Test files
Everything that matches the globs below will be passed to Jest as a test file:
- `src/**/__tests__/**/*.(j|t)s?(x)`
- `src/**/?(*.)(spec|test|t).(j|t)s?(x)`

### Setting up the test framework
You can use `setupTests.ts` in your project root to set up the testing framework before each test.

### Overriding Jest configuration
Currently, overriding Jest configuration is not supported.

## Custom Module Paths
TSN supports custom module path mappings. A default custom path mapping is provided in `tsconfig.json`

```json
{
    "paths": {
        "~/*": ["src/*"]
    }
}
```

This configuration allows you to import any module which resolves absolutely to `src`.

```ts
// src/lib/a/b/Module.ts

// instead of
import Module from '../../../Module'

// you can do
import Module from '~/Module'
```

## TODO

-   [/] support `npm` for all scripts in `scripts`
-   [ ] e2e tests
-   [/] support js, jsx, ts, and tsx files in tests and everything
